@@ -237,7 +237,9 @@ def extract_by_var(vars, state_codes,
             if not os.path.exists(export_tmp_fp):
                 result_df.to_parquet(export_tmp_fp, compression='gzip')
             else:
-                tmp_df = result_df.join(tmp_df, how='left')
+                cols_to_use = tmp_df.columns.difference(result_df.columns)
+                tmp_df = pd.merge(tmp_df, results_df[cols_to_use], left_index=True, right_index=True, how='left')
+                # tmp_df = result_df.join(tmp_df, how='left')
                 tmp_df.to_parquet(export_tmp_fp, compression='gzip')
 
             # record progress
